package com.bwie.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.feign.AuthFeign;
import com.bwie.service.AuthService;
import com.bwie.common.constants.Constants;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.UserLogin;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.concurrent.TimeUnit;

/**
 * @Author: zhx
 * @Package: com.bwie.auth.service.impl
 * @Datetime: 2024/1/3 9:23
 * @Filename: AuthServiceImpl
 * @Description:
 */
@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private AuthFeign authFeign;

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Autowired
    private HttpServletRequest request;

    @Override
    public Result login(UserLogin userLogin) {

        Result<User> result = authFeign.findName(userLogin.getUsername());

        User user = result.getData();

        if(user==null){
           return Result.error("用户不存在");
        }

        if(!user.getPassword().equals(userLogin.getPassword())){
            return Result.error("密码有误");
        }

        HashMap<String, Object> map = new HashMap<>();

        map.put(JwtConstants.DETAILS_USERNAME, JSON.toJSONString(user.getUsername()));

        String token = JwtUtils.createToken(map);

        user.setToken(token);

        redisTemplate.opsForValue().set(JwtConstants.LOGIN_TOKEN,JSON.toJSONString(user),30, TimeUnit.MINUTES);

        return Result.success(user,"登录成功");
    }

    @Override
    public Result getInfo() {
        Object o = redisTemplate.opsForValue().get(JwtConstants.LOGIN_TOKEN);

        User user = JSON.parseObject((String) o, User.class);

        return Result.success(user,"获取成功");
    }

}
