package com.bwie.config;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.amqp.core.*;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.amqp.support.converter.Jackson2JsonMessageConverter;
import org.springframework.amqp.support.converter.MessageConverter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.annotation.PostConstruct;

@Configuration
public class RabbitConfig implements RabbitTemplate.ConfirmCallback,RabbitTemplate.ReturnsCallback {

    public static final String QUEUE = "queue";

    public static final String DIREXCHANGE = "dirExchange";

    public static final String ROUTINGKEY = "key";

    public static final Logger logger = LoggerFactory.getLogger(RabbitConfig.class);

    @Autowired
    private RabbitTemplate rabbitTemplate;

    @Bean
    public MessageConverter messageConverter(){
        return new Jackson2JsonMessageConverter();
    }

    @Bean
    public Queue queue(){
        return new Queue(QUEUE,true);
    }

    @Bean
    public DirectExchange directExchange(){
        return new DirectExchange(DIREXCHANGE);
    }

    @Bean
    public Binding binding(){
        return BindingBuilder.bind(queue()).to(directExchange()).with(ROUTINGKEY);
    }

    @PostConstruct
    public void rabbitTemplate(){
        rabbitTemplate.setConfirmCallback(this);
        rabbitTemplate.setReturnsCallback(this);
    }


    @Override
    public void confirm(CorrelationData correlationData, boolean ack, String s) {

        if(ack){
            logger.info("{}消息抵达交换机",correlationData.getId());
        }else {
            logger.error("{}消息丢失",correlationData.getId());
        }
    }

    @Override
    public void returnedMessage(ReturnedMessage returnedMessage) {
        logger.error("{}消息未抵达队列",returnedMessage.getMessage().getMessageProperties().getMessageId());
    }
}
