package com.bwie.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.domain.*;
import com.bwie.common.domain.request.ItemRequest;
import com.bwie.common.domain.request.ProRequest;
import com.bwie.common.result.PageResult;
import com.bwie.common.result.Result;
import com.bwie.common.utils.FastUtil;
import com.bwie.config.RabbitConfig;
import com.bwie.mapper.ProMapper;
import com.bwie.service.ProService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.UUID;

/**
 * @Author: zhx
 * @Package: com.bwie.service.impl
 * @Datetime: 2024/1/3 11:15
 * @Filename: ProServiceImpl
 * @Description:
 */
@Service
public class ProServiceImpl implements ProService {

    @Autowired
    private ProMapper proMapper;

    @Autowired
    private RabbitTemplate rabbitTemplate;

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Autowired
    private FastUtil fastUtil;

    @Override
    public Result<PageResult<Pro>> list(ProRequest proRequest) {
        PageHelper.startPage(proRequest.getPageNum(),proRequest.getPageSize());


        Object o = redisTemplate.opsForValue().get(JwtConstants.LOGIN_TOKEN);

        User user = JSON.parseObject((String) o, User.class);

        proRequest.setUserId(user.getUserId());

        Long total = 0L;

        if(user.getUserRank()==3){
            List<Pro> list = proMapper.list(proRequest);
            return Result.success(PageResult.toPageResult(total,list),"查询成功");
        }

            List<Pro> list = proMapper.listAll(proRequest);

        return Result.success(PageResult.toPageResult(total,list),"查询成功");

    }

    @Override
    public Result pic(MultipartFile file) {

        String upload = "";

        try {
            upload = fastUtil.upload(file);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }

        return Result.success("http://124.223.114.120:8888/"+upload,"上传成功");
    }

    @Override
    public Result addItem(ItemRequest itemRequest) {

        Object o = redisTemplate.opsForValue().get(JwtConstants.LOGIN_TOKEN);

        User user = JSON.parseObject((String) o, User.class);

        itemRequest.setUserId(user.getUserId());
        int add = proMapper.addItem(itemRequest);

        Aop aop = new Aop("添加", user.getUserId());

        proMapper.addAop(aop);

        return Result.success(add>0?"添加成功":"添加失败");
    }

    @Override
    public void initialize() {
       List<Type> list = proMapper.findAllType();
//项目初始化时请把数据同步到Redis当中
        for (Type type : list) {

            redisTemplate.opsForList().rightPush("key:type",JSON.toJSONString(type));

        }

    }

    @Override
    public Result updState(Pro pro) {

        Object o = redisTemplate.opsForValue().get(JwtConstants.LOGIN_TOKEN);

        User user = JSON.parseObject((String) o, User.class);

        Aop aop = new Aop("提交审核", user.getUserId());

        proMapper.addAop(aop);

        int upd = proMapper.updState(pro.getProId());
        return Result.success(upd>0?"提交审核成功":"提交审核失败");
    }

    @Override
    public Result findType(Integer proId) {

        List<TypeTable> list = proMapper.findType(proId);

        return Result.success(list);
    }

    @Override
    public Result updPlace(Integer proId) {

        int upd = proMapper.updPlace(proId);

        Object o = redisTemplate.opsForValue().get(JwtConstants.LOGIN_TOKEN);

        User user = JSON.parseObject((String) o, User.class);

        Aop aop = new Aop("审核", user.getUserId());

        proMapper.addAop(aop);

        String MQ = "审核成功";



        rabbitTemplate.convertAndSend(RabbitConfig.DIREXCHANGE,RabbitConfig.ROUTINGKEY,MQ,message -> {
            message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
            return message;
        },new CorrelationData(UUID.randomUUID().toString()));



        return Result.success(upd>0?"审核成功":"审核失败");
    }
}
